@@ -125,33 +125,43 @@ predict.modISDM <- function(object, data = NULL, formula = NULL, mesh = NULL,
   if (!is.null(object$temporal$temporalVar)) temporal <- TRUE
   else temporal <- FALSE
   
+  if (!is.null(object$spatCovs$name)) {
   
   if (!any(names(data) %in% object$spatCovs$name)) {
     
-    for (spatCov in object$spatCovs$name) {
-      ##Fix this
-      data[, spatCov] <- inlabru::eval_spatial(where =  data, 
-                                                data = get('spatialcovariates', 
-                                                           envir = object$spatCov$env)[spatCov],
-                                                layer = spatCov)
-      
-      if (any(is.na( data[, spatCov]))) {
-        
-        for (indFix in spatCov) {
-          
-          data[[indFix]] <- inlabru::bru_fill_missing(where =  data, 
-                                                      data = get('spatialcovariates', 
-                                                                 envir = object$spatCov$env)[spatCov],
-                                                      layer = spatCov,
-                                                      values = data[[indFix]])
-          
-        }
-        
-      }
-      
-      
-    }
+    data <- assignCovariate(data = list(data), 
+                                          covariateEnv = object$spatCovs$env,
+                                          covariateNames = object$spatCovs$name, 
+                                          timeVariable = object$temporal$temporalVar, 
+                                          timeData = object$temporal$temporalIn, 
+                                          projection = fmesher::fm_wkt(object$bru_info$lhoods[[1]]$data), 
+                                          IPS = TRUE)
     
+    # for (spatCov in object$spatCovs$name) {
+    #   ##Fix this
+    #   data[, spatCov] <- inlabru::eval_spatial(where =  data, 
+    #                                             data = get('spatialcovariates', 
+    #                                                        envir = object$spatCov$env)[spatCov],
+    #                                             layer = spatCov)
+    #   
+    #   if (any(is.na( data[, spatCov]))) {
+    #     
+    #     for (indFix in spatCov) {
+    #       
+    #       data[[indFix]] <- inlabru::bru_fill_missing(where =  data, 
+    #                                                   data = get('spatialcovariates', 
+    #                                                              envir = object$spatCov$env)[spatCov],
+    #                                                   layer = spatCov,
+    #                                                   values = data[[indFix]])
+    #       
+    #     }
+    #     
+    #   }
+    #   
+    #   
+    # }
+    
+  }
   }
   
   if (object$spatial$points == 'correlate' & !'._dataset_index_var_.' %in% names(data)) {
